/*
 * Copyright 2024 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


  // DESCRIPTION:
  // This test stops towards the end of a regular sleep session.
  // - Test that we have an overarching Sleep session that starts around 75-90 and lasts
  //   until we shut activity down
  // - Test that we have 3 full deep sleep sessions.
  // ----------------------------------------------------------------
  // Sample captured at: 2016-05-19 21:05:00 local, 2016-05-20 04:05:00 GMT
  AlgDlsMinuteData *activity_sample_sleep_shut_down_1(int *len) {
    // The unit tests parse the //> TEST_.* lines below for test values
    //> TEST_NAME sleep_shut_down_1
    //> TEST_VERSION 3
    //> TEST_TOTAL -1
    //> TEST_TOTAL_MIN 350
    //> TEST_TOTAL_MAX 370
    //> TEST_DEEP -1
    //> TEST_DEEP_MIN -1
    //> TEST_DEEP_MAX -1
    //> TEST_START_AT 82
    //> TEST_START_AT_MIN 75
    //> TEST_START_AT_MAX 90
    //> TEST_END_AT -1
    //> TEST_END_AT_MIN 430
    //> TEST_END_AT_MAX 470
    //> TEST_CUR_STATE_ELAPSED -1
    //> TEST_CUR_STATE_ELAPSED_MIN -1
    //> TEST_CUR_STATE_ELAPSED_MAX -1
    //> TEST_IN_SLEEP 0
    //> TEST_IN_SLEEP_MIN 0
    //> TEST_IN_SLEEP_MAX 0
    //> TEST_IN_DEEP_SLEEP 0
    //> TEST_IN_DEEP_SLEEP_MIN 0
    //> TEST_IN_DEEP_SLEEP_MAX 0
    //> TEST_WEIGHT 1.0
    //> TEST_FORCE_SHUT_DOWN_AT 450

    // list of: {steps, orientation, vmc, light, plugged_in}
    static AlgDlsMinuteData samples[] = {
      // 0: Local time: 2016-05-19 09:05:00 PM
      { 0, 0x74, 59, 155, 0},
      { 0, 0x54, 968, 166, 0},
      { 0, 0x64, 429, 160, 0},
      { 0, 0x77, 992, 168, 0},
      { 0, 0x58, 1835, 170, 0},
      { 0, 0x55, 1379, 162, 0},
      { 0, 0x64, 1440, 164, 0},
      { 0, 0x62, 837, 164, 0},
      { 12, 0x53, 7904, 176, 0},
      { 0, 0x74, 290, 175, 0},
      { 0, 0x75, 1456, 170, 0},
      { 0, 0x77, 834, 174, 0},
      { 0, 0x74, 1754, 160, 0},
      { 0, 0x73, 1030, 157, 0},
      { 0, 0x81, 92, 153, 0},
      // 15: Local time: 2016-05-19 09:20:00 PM
      { 0, 0x74, 3906, 175, 0},
      { 0, 0x73, 2781, 168, 0},
      { 0, 0x51, 1568, 154, 0},
      { 0, 0x42, 477, 153, 0},
      { 0, 0x41, 167, 151, 0},
      { 0, 0x51, 1670, 154, 0},
      { 0, 0x51, 260, 138, 0},
      { 0, 0x51, 787, 156, 0},
      { 0, 0x62, 1150, 172, 0},
      { 0, 0x41, 2070, 152, 0},
      { 0, 0x51, 1533, 162, 0},
      { 0, 0x51, 229, 164, 0},
      { 0, 0x51, 144, 160, 0},
      { 0, 0x72, 720, 167, 0},
      { 0, 0x73, 277, 165, 0},
      // 30: Local time: 2016-05-19 09:35:00 PM
      { 0, 0x73, 52, 157, 0},
      { 0, 0x54, 1941, 173, 0},
      { 0, 0x32, 1716, 155, 0},
      { 0, 0x73, 1631, 152, 0},
      { 0, 0x73, 0, 167, 0},
      { 0, 0x68, 1038, 177, 0},
      { 0, 0x49, 171, 173, 0},
      { 0, 0x55, 3197, 133, 0},
      { 0, 0x74, 441, 158, 0},
      { 0, 0x63, 2972, 176, 0},
      { 0, 0x64, 111, 175, 0},
      { 0, 0x44, 899, 163, 0},
      { 0, 0x54, 1677, 165, 0},
      { 15, 0x64, 2905, 176, 0},
      { 0, 0x64, 1880, 174, 0},
      // 45: Local time: 2016-05-19 09:50:00 PM
      { 10, 0x43, 2854, 153, 0},
      { 61, 0x42, 9491, 151, 0},
      { 16, 0x65, 10215, 134, 0},
      { 0, 0x55, 3016, 132, 0},
      { 0, 0x67, 2078, 135, 0},
      { 16, 0x67, 5711, 146, 0},
      { 0, 0x77, 3877, 136, 0},
      { 0, 0x78, 3814, 132, 0},
      { 0, 0x53, 88, 132, 0},
      { 0, 0x76, 828, 137, 0},
      { 0, 0x68, 2650, 139, 0},
      { 0, 0x64, 3438, 131, 0},
      { 0, 0x43, 366, 129, 0},
      { 0, 0x53, 1057, 134, 0},
      { 0, 0x54, 708, 130, 0},
      // 60: Local time: 2016-05-19 10:05:00 PM
      { 0, 0x54, 1394, 217, 0},
      { 16, 0x45, 9447, 155, 0},
      { 61, 0x34, 3253, 153, 0},
      { 8, 0x44, 2739, 136, 0},
      { 0, 0x62, 6031, 238, 0},
      { 0, 0x8d, 0, 237, 0},
      { 0, 0x8c, 593, 237, 0},
      { 0, 0x8d, 0, 238, 0},
      { 0, 0x8e, 0, 238, 0},
      { 0, 0x8e, 0, 237, 0},
      { 0, 0x8e, 0, 237, 0},
      { 0, 0x8e, 0, 238, 0},
      { 0, 0x8e, 0, 166, 0},
      { 9, 0x80, 735, 181, 0},
      { 15, 0x82, 656, 192, 0},
      // 75: Local time: 2016-05-19 10:20:00 PM
      { 0, 0x82, 0, 182, 0},
      { 0, 0x82, 0, 181, 0},
      { 0, 0x82, 0, 182, 0},
      { 0, 0x82, 0, 181, 0},
      { 0, 0x82, 1309, 201, 0},
      { 0, 0x82, 660, 182, 0},
      { 0, 0x82, 0, 181, 0},
      { 0, 0x82, 0, 181, 0},
      { 0, 0x82, 0, 181, 0},
      { 0, 0x82, 0, 181, 0},
      { 0, 0x82, 0, 180, 0},
      { 0, 0x82, 0, 179, 0},
      { 0, 0x82, 0, 179, 0},
      { 0, 0x82, 0, 179, 0},
      { 0, 0x82, 0, 179, 0},
      // 90: Local time: 2016-05-19 10:35:00 PM
      { 0, 0x82, 0, 179, 0},
      { 0, 0x82, 0, 180, 0},
      { 0, 0x82, 0, 179, 0},
      { 0, 0x82, 0, 121, 0},
      { 0, 0x82, 0, 122, 0},
      { 0, 0x82, 0, 122, 0},
      { 0, 0x82, 0, 121, 0},
      { 0, 0x58, 1521, 208, 0},
      { 17, 0x69, 3034, 125, 0},
      { 0, 0x50, 1281, 125, 0},
      { 8, 0x5d, 1639, 126, 0},
      { 0, 0x4d, 0, 127, 0},
      { 0, 0x4d, 0, 128, 0},
      { 0, 0x4d, 0, 127, 0},
      { 0, 0x4d, 0, 129, 0},
      // 105: Local time: 2016-05-19 10:50:00 PM
      { 0, 0x4d, 0, 129, 0},
      { 0, 0x4d, 0, 128, 0},
      { 0, 0x4d, 3, 128, 0},
      { 0, 0x4d, 0, 129, 0},
      { 0, 0x5d, 751, 129, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 129, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 129, 0},
      { 0, 0x5d, 0, 128, 0},
      // 120: Local time: 2016-05-19 11:05:00 PM
      { 0, 0x5d, 0, 129, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x5c, 0, 129, 0},
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x5c, 0, 129, 0},
      { 0, 0x5c, 0, 129, 0},
      { 0, 0x5c, 0, 128, 0},
      // 135: Local time: 2016-05-19 11:20:00 PM
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x6c, 161, 127, 0},
      { 0, 0x79, 0, 128, 0},
      { 0, 0x79, 0, 128, 0},
      { 0, 0x79, 0, 129, 0},
      { 0, 0x79, 0, 140, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      // 150: Local time: 2016-05-19 11:35:00 PM
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x6b, 845, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      // 165: Local time: 2016-05-19 11:50:00 PM
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 105, 141, 0},
      // 180: Local time: 2016-05-20 12:05:00 AM
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},

      // Manually inserted record
      { 0, 0x5b, 0, 141, 0},


      // 195: Local time: 2016-05-20 12:21:00 AM
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 134, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      // 210: Local time: 2016-05-20 12:36:00 AM
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x6b, 44, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      // 225: Local time: 2016-05-20 12:51:00 AM
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 577, 141, 0},
      { 0, 0x1d, 142, 141, 0},
      // 240: Local time: 2016-05-20 01:06:00 AM
      { 0, 0x1d, 0, 141, 0},
      { 0, 0x1d, 0, 141, 0},
      { 0, 0x1d, 0, 141, 0},
      { 0, 0x1d, 0, 141, 0},
      { 0, 0x1d, 0, 141, 0},
      { 0, 0x1d, 0, 142, 0},
      { 0, 0x1d, 0, 142, 0},
      { 0, 0x1d, 0, 142, 0},
      { 0, 0x1d, 52, 142, 0},
      { 0, 0x1e, 0, 141, 0},
      { 0, 0x1e, 0, 141, 0},
      { 0, 0x1e, 0, 141, 0},
      { 0, 0x1e, 0, 141, 0},
      { 0, 0x1e, 0, 141, 0},
      { 0, 0x1d, 497, 141, 0},
      // 255: Local time: 2016-05-20 01:21:00 AM
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x7a, 512, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 134, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 244, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      // 270: Local time: 2016-05-20 01:36:00 AM
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 444, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      // 285: Local time: 2016-05-20 01:51:00 AM
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 497, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      // 300: Local time: 2016-05-20 02:06:00 AM
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 273, 141, 0},
      { 0, 0x6b, 261, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      // 315: Local time: 2016-05-20 02:21:00 AM
      { 0, 0x6b, 1650, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 134, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 547, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      // 330: Local time: 2016-05-20 02:36:00 AM
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 271, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x69, 454, 141, 0},
      // 345: Local time: 2016-05-20 02:51:00 AM
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x69, 0, 140, 0},
      { 0, 0x69, 0, 141, 0},
      { 0, 0x69, 0, 141, 0},
      { 0, 0x69, 0, 141, 0},
      { 0, 0x69, 0, 141, 0},
      { 0, 0x69, 0, 141, 0},
      { 0, 0x69, 0, 140, 0},
      { 0, 0x69, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6b, 1308, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      // 360: Local time: 2016-05-20 03:06:00 AM
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x7a, 342, 140, 0},
      { 0, 0x78, 0, 140, 0},
      { 0, 0x78, 0, 140, 0},
      { 0, 0x78, 287, 140, 0},
      { 0, 0x78, 0, 140, 0},
      { 0, 0x78, 0, 140, 0},
      // 375: Local time: 2016-05-20 03:21:00 AM
      { 0, 0x78, 0, 140, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 0, 140, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 0, 134, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 82, 141, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 17, 141, 0},
      // 390: Local time: 2016-05-20 03:36:00 AM
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 140, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 57, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 140, 0},
      // 405: Local time: 2016-05-20 03:51:00 AM
      { 0, 0x79, 0, 140, 0},
      { 0, 0x79, 5, 140, 0},
      { 0, 0x69, 2149, 141, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6a, 1071, 140, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 140, 0},
      // 420: Local time: 2016-05-20 04:06:00 AM
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 1334, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      // 435: Local time: 2016-05-20 04:21:00 AM
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 133, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      // 450: Local time: 2016-05-20 04:36:00 AM
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 408, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 28, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x5b, 17, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      // 465: Local time: 2016-05-20 04:51:00 AM
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 140, 0},
      { 0, 0x5b, 156, 140, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 7, 141, 0},
      { 0, 0x6b, 735, 141, 0},
      { 0, 0x6b, 377, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      // 480: Local time: 2016-05-20 05:06:00 AM
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x25, 880, 140, 0},
      { 0, 0x25, 0, 140, 0},
      { 0, 0x25, 0, 140, 0},
      { 0, 0x17, 624, 139, 0},
      { 0, 0x3b, 491, 139, 0},
      { 0, 0x3b, 0, 140, 0},
      { 0, 0x3b, 0, 140, 0},
      { 0, 0x3b, 0, 140, 0},
      { 0, 0x4b, 65, 141, 0},
      { 0, 0x4b, 510, 140, 0},
      { 0, 0x45, 4409, 140, 0},
      // 495: Local time: 2016-05-20 05:21:00 AM
      { 0, 0x37, 0, 140, 0},
      { 32, 0x44, 8847, 149, 0},
      { 4, 0x7a, 2084, 139, 0},
      { 0, 0x6a, 0, 139, 0},
      { 0, 0x6a, 0, 139, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x79, 4162, 139, 0},
      { 0, 0x62, 2787, 139, 0},
      { 0, 0x62, 0, 132, 0},
      { 0, 0x62, 13, 140, 0},
      { 0, 0x62, 0, 140, 0},
      { 0, 0x61, 0, 140, 0},
      { 0, 0x61, 0, 141, 0},
      { 0, 0x61, 0, 141, 0},
      { 0, 0x52, 466, 141, 0},
      // 510: Local time: 2016-05-20 05:36:00 AM
      { 0, 0x33, 0, 141, 0},
      { 0, 0x33, 0, 141, 0},
      { 0, 0x33, 0, 141, 0},
      { 0, 0x33, 0, 141, 0},
      { 0, 0x33, 0, 141, 0},
      { 0, 0x33, 0, 141, 0},
      { 0, 0x33, 5, 141, 0},
      { 0, 0x33, 0, 141, 0},
      { 0, 0x33, 0, 141, 0},
      { 0, 0x33, 0, 141, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 141, 0},
      { 0, 0x43, 0, 142, 0},
      // 525: Local time: 2016-05-20 05:51:00 AM
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 143, 0},
      { 0, 0x43, 0, 143, 0},
      // 540: Local time: 2016-05-20 06:06:00 AM
      { 0, 0x43, 0, 143, 0},
      { 0, 0x43, 0, 145, 0},
      { 0, 0x4d, 1007, 153, 0},
      { 0, 0x3d, 0, 153, 0},
      { 0, 0x3d, 0, 153, 0},
      { 0, 0x3d, 1034, 148, 0},
      { 0, 0x2d, 0, 148, 0},
      { 0, 0x2d, 0, 147, 0},
      { 0, 0x2d, 0, 148, 0},
      { 0, 0x2d, 0, 148, 0},
      { 0, 0x2d, 0, 149, 0},
      { 0, 0x2d, 0, 148, 0},
      { 0, 0x2d, 0, 151, 0},
      { 0, 0x2d, 0, 149, 0},
      { 0, 0x2d, 0, 150, 0},
      // 555: Local time: 2016-05-20 06:21:00 AM
      { 0, 0x2d, 0, 147, 0},
      { 0, 0x2d, 0, 148, 0},
      { 0, 0x2d, 0, 147, 0},
      { 0, 0x4c, 1708, 166, 0},
      { 0, 0x6b, 157, 167, 0},
      { 0, 0x6b, 50, 168, 0},
      { 0, 0x6b, 0, 169, 0},
      { 0, 0x6b, 0, 169, 0},
      { 0, 0x7a, 801, 134, 0},
      { 0, 0x77, 0, 141, 0},
      { 0, 0x77, 0, 141, 0},
      { 0, 0x77, 0, 141, 0},
      { 0, 0x3d, 537, 141, 0},
      { 0, 0x2e, 0, 141, 0},
      { 0, 0x2e, 0, 141, 0},
      // 570: Local time: 2016-05-20 06:36:00 AM
      { 0, 0x2e, 0, 141, 0},
      { 0, 0x2e, 0, 141, 0},
      { 0, 0x2e, 25, 151, 0},
      { 0, 0x2d, 90, 141, 0},
      { 0, 0x2d, 0, 141, 0},
      { 0, 0x2d, 0, 141, 0},
      { 0, 0x51, 1294, 159, 0},
      { 0, 0x62, 0, 156, 0},
      { 0, 0x61, 1, 161, 0},
      { 0, 0x61, 0, 163, 0},
      { 0, 0x61, 17, 160, 0},
      { 0, 0x62, 0, 160, 0},
      { 0, 0x62, 0, 160, 0},
      { 0, 0x62, 0, 163, 0},
      { 0, 0x62, 0, 160, 0},
      // 585: Local time: 2016-05-20 06:51:00 AM
      { 0, 0x60, 385, 165, 0},
      { 0, 0x60, 287, 169, 0},
      { 0, 0x67, 6341, 154, 0},
      { 0, 0x65, 0, 158, 0},
      { 0, 0x65, 0, 154, 0},
      { 0, 0x65, 0, 156, 0},
      { 0, 0x65, 0, 156, 0},
      { 0, 0x65, 0, 155, 0},
      { 0, 0x65, 0, 155, 0},
      { 0, 0x65, 0, 154, 0},
      { 0, 0x65, 0, 152, 0},
      { 0, 0x66, 1354, 152, 0},
      { 0, 0x7a, 4397, 153, 0},
      { 0, 0x6b, 755, 171, 0},
      { 0, 0x1b, 470, 141, 0},
      // 600: Local time: 2016-05-20 07:06:00 AM
      { 0, 0x1c, 0, 141, 0},
      { 0, 0x1b, 404, 224, 0},
      { 0, 0x1a, 893, 129, 0},
      { 0, 0x1b, 0, 129, 0},
      { 0, 0x1c, 0, 128, 0},
      { 0, 0x1b, 0, 129, 0},
      { 0, 0x1b, 115, 151, 0},
      { 0, 0x3b, 1074, 158, 0},
      { 0, 0x4b, 0, 160, 0},
      { 0, 0x31, 3217, 152, 0},
      { 0, 0x42, 4305, 149, 0},
      { 0, 0x23, 1758, 147, 0},
      { 0, 0x41, 4985, 155, 0},
      { 28, 0x52, 5444, 149, 0},
      { 0, 0x32, 11340, 163, 0},
      // 615: Local time: 2016-05-20 07:21:00 AM
      { 16, 0x42, 6476, 154, 0},
      { 0, 0x32, 8102, 154, 0},
      { 13, 0x41, 6921, 172, 0},
      { 17, 0x52, 7320, 157, 0},
      { 117, 0x44, 18847, 227, 0},
      { 169, 0x44, 23617, 237, 0},
      { 170, 0x44, 24526, 224, 0},
      { 169, 0x44, 25436, 230, 0},
      { 153, 0x44, 22845, 228, 0},
      { 125, 0x63, 19957, 236, 0},
      { 71, 0x43, 10261, 231, 0},
      { 171, 0x44, 26540, 243, 0},
      { 157, 0x43, 23827, 232, 0},
      { 159, 0x34, 23139, 243, 0},
      { 171, 0x44, 25505, 245, 0},
      // 630: Local time: 2016-05-20 07:36:00 AM
      { 173, 0x44, 26724, 239, 0},
      { 166, 0x44, 25688, 243, 0},
      { 164, 0x43, 25603, 233, 0},
      { 154, 0x34, 24422, 235, 0},
      { 137, 0x32, 17819, 231, 0},
      { 108, 0x44, 21616, 156, 0},
      { 29, 0x42, 8636, 161, 0},
      { 0, 0x8f, 30, 164, 0},
      { 0, 0x8f, 0, 162, 0},
      { 0, 0x7f, 4211, 128, 0},
      { 0, 0xe, 28, 125, 0},
      { 0, 0xe, 0, 125, 0},
      { 0, 0xe, 17, 123, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0xe, 0, 122, 0},
      // 645: Local time: 2016-05-20 07:52:00 AM
      { 0, 0xe, 0, 123, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0xe, 0, 121, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0xe, 0, 121, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0x2, 1702, 168, 0},
      { 0, 0x42, 7069, 224, 0},
      { 0, 0x43, 7012, 149, 0},
      { 0, 0x42, 5072, 157, 0},
      // 660: Local time: 2016-05-20 08:07:00 AM
      { 13, 0x42, 5721, 159, 0},
      { 0, 0x33, 5436, 155, 0},
      { 0, 0x52, 2228, 191, 0},
      { 0, 0x42, 5251, 187, 0},
      { 0, 0x44, 4134, 188, 0},
      { 0, 0x31, 4710, 190, 0},
      { 13, 0x43, 6077, 154, 0},
      { 17, 0x42, 7089, 165, 0},
      { 0, 0x34, 2517, 161, 0},
      { 76, 0x44, 8780, 165, 0},
      { 20, 0x64, 11094, 183, 0},
      { 12, 0x65, 7077, 199, 0},
      { 0, 0x56, 2881, 209, 0},
      { 0, 0x78, 830, 232, 0},
      { 0, 0x56, 1202, 206, 0},
      // 675: Local time: 2016-05-20 08:22:00 AM
      { 0, 0x66, 3640, 229, 0},
      { 0, 0x56, 2355, 230, 0},
      { 0, 0x46, 1525, 239, 0},
      { 0, 0x56, 1722, 231, 0},
      { 0, 0x68, 743, 241, 0},
      { 13, 0x66, 2708, 220, 0},
      { 0, 0x77, 3205, 231, 0},
      { 0, 0x76, 5295, 240, 0},
      { 0, 0x64, 3398, 235, 0},
      { 0, 0x77, 1878, 232, 0},
      { 0, 0x77, 1119, 237, 0},
      { 0, 0x77, 2265, 228, 0},
      { 0, 0x76, 653, 241, 0},
      { 0, 0x43, 1086, 222, 0},
      { 0, 0x44, 1009, 215, 0},
      // 690: Local time: 2016-05-20 08:37:00 AM
      { 0, 0x44, 718, 218, 0},
      { 0, 0x54, 2140, 228, 0},
      { 0, 0x65, 568, 217, 0},
      { 0, 0x68, 3373, 218, 0},
      { 15, 0x74, 2305, 152, 0},
      { 0, 0x66, 2708, 201, 0},
      { 0, 0x79, 2375, 239, 0},
      { 15, 0x75, 10768, 179, 0},
      { 5, 0x44, 3575, 231, 0},
      { 16, 0x43, 11891, 237, 0},
      { 132, 0x44, 9108, 241, 0},
      { 134, 0x41, 12303, 228, 0},
      { 75, 0x42, 10154, 170, 0},
      { 17, 0x42, 6476, 174, 0},
      { 0, 0x45, 161, 210, 0},
      // 705: Local time: 2016-05-20 08:52:00 AM
      { 0, 0x44, 418, 235, 0},
      { 0, 0x34, 529, 144, 0},
      { 0, 0x44, 1993, 234, 0},
      { 0, 0x44, 895, 189, 0},
      { 0, 0x44, 1402, 196, 0},
      { 0, 0x45, 1866, 198, 0},
      { 0, 0x45, 1743, 202, 0},
      { 0, 0x44, 200, 178, 0},
      { 16, 0x45, 4072, 214, 0},
      { 20, 0x55, 3492, 171, 0},
      { 0, 0x44, 943, 217, 0},
      { 0, 0x64, 963, 194, 0},
      { 0, 0x44, 466, 244, 0},
      { 0, 0x54, 543, 201, 0},
      { 0, 0x54, 40, 202, 0},
      // 720: Local time: 2016-05-20 09:07:00 AM
      { 0, 0x54, 394, 205, 0},
      { 0, 0x44, 776, 200, 0},
      { 0, 0x34, 319, 189, 0},
      { 0, 0x44, 231, 202, 0},
      { 0, 0x44, 154, 160, 0},
      { 0, 0x44, 362, 174, 0},
      { 0, 0x44, 863, 178, 0},
      { 0, 0x44, 235, 198, 0},
      { 0, 0x34, 599, 186, 0},
      { 0, 0x34, 2650, 206, 0},
      { 40, 0x65, 4484, 206, 0},
      { 0, 0x55, 2161, 212, 0},
      { 0, 0x54, 1905, 186, 0},
      { 0, 0x44, 2506, 158, 0},
      { 60, 0x42, 7836, 237, 0},
      // 735: Local time: 2016-05-20 09:22:00 AM
      { 65, 0x52, 8008, 198, 0},
      { 81, 0x65, 6245, 164, 0},
      { 116, 0x55, 8784, 167, 0},
      { 5, 0x34, 4313, 155, 0},
      { 20, 0x43, 7667, 174, 0},
      { 50, 0x52, 7869, 168, 0},
      { 57, 0x54, 4964, 169, 0},
      { 0, 0x54, 4528, 172, 0},
      { 0, 0x63, 319, 175, 0},
      { 0, 0x63, 156, 163, 0},
      { 0, 0x63, 441, 162, 0},
      { 0, 0x63, 34, 159, 0},
      { 0, 0x63, 28, 162, 0},
      { 22, 0x52, 2970, 165, 0},
      { 0, 0x53, 2548, 162, 0},
      // 750: Local time: 2016-05-20 09:37:00 AM
      { 0, 0x63, 179, 163, 0},
      { 0, 0x63, 23, 160, 0},
      { 0, 0x63, 19, 163, 0},
      { 0, 0x63, 55, 159, 0},
      { 0, 0x63, 100, 174, 0},
      { 0, 0x63, 40, 174, 0},
      { 0, 0x63, 2296, 176, 0},
      { 0, 0x63, 1539, 159, 0},
      { 0, 0x63, 784, 161, 0},
      { 0, 0x63, 1088, 161, 0},
      { 0, 0x53, 3964, 161, 0},
      { 0, 0x62, 1803, 159, 0},
      { 0, 0x63, 2209, 158, 0},
      { 0, 0x63, 1288, 161, 0},
      { 0, 0x63, 127, 163, 0},
      // 765: Local time: 2016-05-20 09:52:00 AM
      { 0, 0x73, 196, 159, 0},
      { 0, 0x63, 708, 162, 0},
      { 12, 0x63, 2619, 160, 0},
      { 0, 0x63, 3847, 155, 0},
      { 0, 0x53, 1970, 160, 0},
      { 0, 0x63, 113, 161, 0},
      { 0, 0x63, 801, 159, 0},
      { 0, 0x53, 3403, 163, 0},
      { 0, 0x44, 5164, 155, 0},
      { 0, 0x31, 3504, 153, 0},
      { 0, 0x40, 1749, 154, 0},
      { 0, 0x33, 2513, 158, 0},
      { 0, 0x54, 2070, 156, 0},
      { 24, 0x52, 2342, 171, 0},
      { 4, 0x44, 2826, 169, 0},
    };
    *len = ARRAY_LENGTH(samples);
    return samples;
  }


  // DESCRIPTION:
  // This test stops towards the end of a deep sleep session.
  // - Test that we have an overarching Sleep session that starts around 75-90 and lasts
  //   until we shut activity down
  // - Test that we have 2 full deep sleep sessions, and cut off the one in progress at
  //   18-19 minutes into it. It should not be saved. We judge this based on total time
  //   in deep sleep
  // ----------------------------------------------------------------
  // Sample captured at: 2016-05-19 21:05:00 local, 2016-05-20 04:05:00 GMT
  AlgDlsMinuteData *activity_sample_sleep_shut_down_2(int *len) {
    // The unit tests parse the //> TEST_.* lines below for test values
    //> TEST_NAME sleep_shut_down_2
    //> TEST_VERSION 3
    //> TEST_TOTAL -1
    //> TEST_TOTAL_MIN 305
    //> TEST_TOTAL_MAX 325
    //> TEST_DEEP 128
    //> TEST_DEEP_MIN 120
    //> TEST_DEEP_MAX 140
    //> TEST_START_AT 82
    //> TEST_START_AT_MIN 75
    //> TEST_START_AT_MAX 90
    //> TEST_END_AT -1
    //> TEST_END_AT_MIN 390
    //> TEST_END_AT_MAX 420
    //> TEST_CUR_STATE_ELAPSED -1
    //> TEST_CUR_STATE_ELAPSED_MIN -1
    //> TEST_CUR_STATE_ELAPSED_MAX -1
    //> TEST_IN_SLEEP 0
    //> TEST_IN_SLEEP_MIN 0
    //> TEST_IN_SLEEP_MAX 0
    //> TEST_IN_DEEP_SLEEP -1
    //> TEST_IN_DEEP_SLEEP_MIN -1
    //> TEST_IN_DEEP_SLEEP_MAX -1
    //> TEST_WEIGHT 1.0
    //> TEST_FORCE_SHUT_DOWN_AT 396

    // list of: {steps, orientation, vmc, light, plugged_in}
    static AlgDlsMinuteData samples[] = {
      // 0: Local time: 2016-05-19 09:05:00 PM
      { 0, 0x74, 59, 155, 0},
      { 0, 0x54, 968, 166, 0},
      { 0, 0x64, 429, 160, 0},
      { 0, 0x77, 992, 168, 0},
      { 0, 0x58, 1835, 170, 0},
      { 0, 0x55, 1379, 162, 0},
      { 0, 0x64, 1440, 164, 0},
      { 0, 0x62, 837, 164, 0},
      { 12, 0x53, 7904, 176, 0},
      { 0, 0x74, 290, 175, 0},
      { 0, 0x75, 1456, 170, 0},
      { 0, 0x77, 834, 174, 0},
      { 0, 0x74, 1754, 160, 0},
      { 0, 0x73, 1030, 157, 0},
      { 0, 0x81, 92, 153, 0},
      // 15: Local time: 2016-05-19 09:20:00 PM
      { 0, 0x74, 3906, 175, 0},
      { 0, 0x73, 2781, 168, 0},
      { 0, 0x51, 1568, 154, 0},
      { 0, 0x42, 477, 153, 0},
      { 0, 0x41, 167, 151, 0},
      { 0, 0x51, 1670, 154, 0},
      { 0, 0x51, 260, 138, 0},
      { 0, 0x51, 787, 156, 0},
      { 0, 0x62, 1150, 172, 0},
      { 0, 0x41, 2070, 152, 0},
      { 0, 0x51, 1533, 162, 0},
      { 0, 0x51, 229, 164, 0},
      { 0, 0x51, 144, 160, 0},
      { 0, 0x72, 720, 167, 0},
      { 0, 0x73, 277, 165, 0},
      // 30: Local time: 2016-05-19 09:35:00 PM
      { 0, 0x73, 52, 157, 0},
      { 0, 0x54, 1941, 173, 0},
      { 0, 0x32, 1716, 155, 0},
      { 0, 0x73, 1631, 152, 0},
      { 0, 0x73, 0, 167, 0},
      { 0, 0x68, 1038, 177, 0},
      { 0, 0x49, 171, 173, 0},
      { 0, 0x55, 3197, 133, 0},
      { 0, 0x74, 441, 158, 0},
      { 0, 0x63, 2972, 176, 0},
      { 0, 0x64, 111, 175, 0},
      { 0, 0x44, 899, 163, 0},
      { 0, 0x54, 1677, 165, 0},
      { 15, 0x64, 2905, 176, 0},
      { 0, 0x64, 1880, 174, 0},
      // 45: Local time: 2016-05-19 09:50:00 PM
      { 10, 0x43, 2854, 153, 0},
      { 61, 0x42, 9491, 151, 0},
      { 16, 0x65, 10215, 134, 0},
      { 0, 0x55, 3016, 132, 0},
      { 0, 0x67, 2078, 135, 0},
      { 16, 0x67, 5711, 146, 0},
      { 0, 0x77, 3877, 136, 0},
      { 0, 0x78, 3814, 132, 0},
      { 0, 0x53, 88, 132, 0},
      { 0, 0x76, 828, 137, 0},
      { 0, 0x68, 2650, 139, 0},
      { 0, 0x64, 3438, 131, 0},
      { 0, 0x43, 366, 129, 0},
      { 0, 0x53, 1057, 134, 0},
      { 0, 0x54, 708, 130, 0},
      // 60: Local time: 2016-05-19 10:05:00 PM
      { 0, 0x54, 1394, 217, 0},
      { 16, 0x45, 9447, 155, 0},
      { 61, 0x34, 3253, 153, 0},
      { 8, 0x44, 2739, 136, 0},
      { 0, 0x62, 6031, 238, 0},
      { 0, 0x8d, 0, 237, 0},
      { 0, 0x8c, 593, 237, 0},
      { 0, 0x8d, 0, 238, 0},
      { 0, 0x8e, 0, 238, 0},
      { 0, 0x8e, 0, 237, 0},
      { 0, 0x8e, 0, 237, 0},
      { 0, 0x8e, 0, 238, 0},
      { 0, 0x8e, 0, 166, 0},
      { 9, 0x80, 735, 181, 0},
      { 15, 0x82, 656, 192, 0},
      // 75: Local time: 2016-05-19 10:20:00 PM
      { 0, 0x82, 0, 182, 0},
      { 0, 0x82, 0, 181, 0},
      { 0, 0x82, 0, 182, 0},
      { 0, 0x82, 0, 181, 0},
      { 0, 0x82, 1309, 201, 0},
      { 0, 0x82, 660, 182, 0},
      { 0, 0x82, 0, 181, 0},
      { 0, 0x82, 0, 181, 0},
      { 0, 0x82, 0, 181, 0},
      { 0, 0x82, 0, 181, 0},
      { 0, 0x82, 0, 180, 0},
      { 0, 0x82, 0, 179, 0},
      { 0, 0x82, 0, 179, 0},
      { 0, 0x82, 0, 179, 0},
      { 0, 0x82, 0, 179, 0},
      // 90: Local time: 2016-05-19 10:35:00 PM
      { 0, 0x82, 0, 179, 0},
      { 0, 0x82, 0, 180, 0},
      { 0, 0x82, 0, 179, 0},
      { 0, 0x82, 0, 121, 0},
      { 0, 0x82, 0, 122, 0},
      { 0, 0x82, 0, 122, 0},
      { 0, 0x82, 0, 121, 0},
      { 0, 0x58, 1521, 208, 0},
      { 17, 0x69, 3034, 125, 0},
      { 0, 0x50, 1281, 125, 0},
      { 8, 0x5d, 1639, 126, 0},
      { 0, 0x4d, 0, 127, 0},
      { 0, 0x4d, 0, 128, 0},
      { 0, 0x4d, 0, 127, 0},
      { 0, 0x4d, 0, 129, 0},
      // 105: Local time: 2016-05-19 10:50:00 PM
      { 0, 0x4d, 0, 129, 0},
      { 0, 0x4d, 0, 128, 0},
      { 0, 0x4d, 3, 128, 0},
      { 0, 0x4d, 0, 129, 0},
      { 0, 0x5d, 751, 129, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 129, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 129, 0},
      { 0, 0x5d, 0, 128, 0},
      // 120: Local time: 2016-05-19 11:05:00 PM
      { 0, 0x5d, 0, 129, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x5c, 0, 129, 0},
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x5c, 0, 129, 0},
      { 0, 0x5c, 0, 129, 0},
      { 0, 0x5c, 0, 128, 0},
      // 135: Local time: 2016-05-19 11:20:00 PM
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x6c, 161, 127, 0},
      { 0, 0x79, 0, 128, 0},
      { 0, 0x79, 0, 128, 0},
      { 0, 0x79, 0, 129, 0},
      { 0, 0x79, 0, 140, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      // 150: Local time: 2016-05-19 11:35:00 PM
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x6b, 845, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      // 165: Local time: 2016-05-19 11:50:00 PM
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 105, 141, 0},
      // 180: Local time: 2016-05-20 12:05:00 AM
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},

      // Manually inserted record
      { 0, 0x5b, 0, 141, 0},


      // 195: Local time: 2016-05-20 12:21:00 AM
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 134, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      // 210: Local time: 2016-05-20 12:36:00 AM
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x6b, 44, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      // 225: Local time: 2016-05-20 12:51:00 AM
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 577, 141, 0},
      { 0, 0x1d, 142, 141, 0},
      // 240: Local time: 2016-05-20 01:06:00 AM
      { 0, 0x1d, 0, 141, 0},
      { 0, 0x1d, 0, 141, 0},
      { 0, 0x1d, 0, 141, 0},
      { 0, 0x1d, 0, 141, 0},
      { 0, 0x1d, 0, 141, 0},
      { 0, 0x1d, 0, 142, 0},
      { 0, 0x1d, 0, 142, 0},
      { 0, 0x1d, 0, 142, 0},
      { 0, 0x1d, 52, 142, 0},
      { 0, 0x1e, 0, 141, 0},
      { 0, 0x1e, 0, 141, 0},
      { 0, 0x1e, 0, 141, 0},
      { 0, 0x1e, 0, 141, 0},
      { 0, 0x1e, 0, 141, 0},
      { 0, 0x1d, 497, 141, 0},
      // 255: Local time: 2016-05-20 01:21:00 AM
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x7a, 512, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 134, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 244, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      // 270: Local time: 2016-05-20 01:36:00 AM
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 444, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      // 285: Local time: 2016-05-20 01:51:00 AM
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 497, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      // 300: Local time: 2016-05-20 02:06:00 AM
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 273, 141, 0},
      { 0, 0x6b, 261, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      // 315: Local time: 2016-05-20 02:21:00 AM
      { 0, 0x6b, 1650, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 134, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 547, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      // 330: Local time: 2016-05-20 02:36:00 AM
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 271, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x69, 454, 141, 0},
      // 345: Local time: 2016-05-20 02:51:00 AM
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x69, 0, 140, 0},
      { 0, 0x69, 0, 141, 0},
      { 0, 0x69, 0, 141, 0},
      { 0, 0x69, 0, 141, 0},
      { 0, 0x69, 0, 141, 0},
      { 0, 0x69, 0, 141, 0},
      { 0, 0x69, 0, 140, 0},
      { 0, 0x69, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6b, 1308, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      // 360: Local time: 2016-05-20 03:06:00 AM
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x7a, 342, 140, 0},
      { 0, 0x78, 0, 140, 0},
      { 0, 0x78, 0, 140, 0},
      { 0, 0x78, 287, 140, 0},
      { 0, 0x78, 0, 140, 0},
      { 0, 0x78, 0, 140, 0},
      // 375: Local time: 2016-05-20 03:21:00 AM
      { 0, 0x78, 0, 140, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 0, 140, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 0, 134, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 82, 141, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 17, 141, 0},
      // 390: Local time: 2016-05-20 03:36:00 AM
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 140, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 57, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 140, 0},
      // 405: Local time: 2016-05-20 03:51:00 AM
      { 0, 0x79, 0, 140, 0},
      { 0, 0x79, 5, 140, 0},
      { 0, 0x69, 2149, 141, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6a, 1071, 140, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 140, 0},
      // 420: Local time: 2016-05-20 04:06:00 AM
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 1334, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      // 435: Local time: 2016-05-20 04:21:00 AM
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 133, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      // 450: Local time: 2016-05-20 04:36:00 AM
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 408, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 28, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x5b, 17, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      // 465: Local time: 2016-05-20 04:51:00 AM
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 140, 0},
      { 0, 0x5b, 156, 140, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 7, 141, 0},
      { 0, 0x6b, 735, 141, 0},
      { 0, 0x6b, 377, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      // 480: Local time: 2016-05-20 05:06:00 AM
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x25, 880, 140, 0},
      { 0, 0x25, 0, 140, 0},
      { 0, 0x25, 0, 140, 0},
      { 0, 0x17, 624, 139, 0},
      { 0, 0x3b, 491, 139, 0},
      { 0, 0x3b, 0, 140, 0},
      { 0, 0x3b, 0, 140, 0},
      { 0, 0x3b, 0, 140, 0},
      { 0, 0x4b, 65, 141, 0},
      { 0, 0x4b, 510, 140, 0},
      { 0, 0x45, 4409, 140, 0},
      // 495: Local time: 2016-05-20 05:21:00 AM
      { 0, 0x37, 0, 140, 0},
      { 32, 0x44, 8847, 149, 0},
      { 4, 0x7a, 2084, 139, 0},
      { 0, 0x6a, 0, 139, 0},
      { 0, 0x6a, 0, 139, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x79, 4162, 139, 0},
      { 0, 0x62, 2787, 139, 0},
      { 0, 0x62, 0, 132, 0},
      { 0, 0x62, 13, 140, 0},
      { 0, 0x62, 0, 140, 0},
      { 0, 0x61, 0, 140, 0},
      { 0, 0x61, 0, 141, 0},
      { 0, 0x61, 0, 141, 0},
      { 0, 0x52, 466, 141, 0},
      // 510: Local time: 2016-05-20 05:36:00 AM
      { 0, 0x33, 0, 141, 0},
      { 0, 0x33, 0, 141, 0},
      { 0, 0x33, 0, 141, 0},
      { 0, 0x33, 0, 141, 0},
      { 0, 0x33, 0, 141, 0},
      { 0, 0x33, 0, 141, 0},
      { 0, 0x33, 5, 141, 0},
      { 0, 0x33, 0, 141, 0},
      { 0, 0x33, 0, 141, 0},
      { 0, 0x33, 0, 141, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 141, 0},
      { 0, 0x43, 0, 142, 0},
      // 525: Local time: 2016-05-20 05:51:00 AM
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 143, 0},
      { 0, 0x43, 0, 143, 0},
      // 540: Local time: 2016-05-20 06:06:00 AM
      { 0, 0x43, 0, 143, 0},
      { 0, 0x43, 0, 145, 0},
      { 0, 0x4d, 1007, 153, 0},
      { 0, 0x3d, 0, 153, 0},
      { 0, 0x3d, 0, 153, 0},
      { 0, 0x3d, 1034, 148, 0},
      { 0, 0x2d, 0, 148, 0},
      { 0, 0x2d, 0, 147, 0},
      { 0, 0x2d, 0, 148, 0},
      { 0, 0x2d, 0, 148, 0},
      { 0, 0x2d, 0, 149, 0},
      { 0, 0x2d, 0, 148, 0},
      { 0, 0x2d, 0, 151, 0},
      { 0, 0x2d, 0, 149, 0},
      { 0, 0x2d, 0, 150, 0},
      // 555: Local time: 2016-05-20 06:21:00 AM
      { 0, 0x2d, 0, 147, 0},
      { 0, 0x2d, 0, 148, 0},
      { 0, 0x2d, 0, 147, 0},
      { 0, 0x4c, 1708, 166, 0},
      { 0, 0x6b, 157, 167, 0},
      { 0, 0x6b, 50, 168, 0},
      { 0, 0x6b, 0, 169, 0},
      { 0, 0x6b, 0, 169, 0},
      { 0, 0x7a, 801, 134, 0},
      { 0, 0x77, 0, 141, 0},
      { 0, 0x77, 0, 141, 0},
      { 0, 0x77, 0, 141, 0},
      { 0, 0x3d, 537, 141, 0},
      { 0, 0x2e, 0, 141, 0},
      { 0, 0x2e, 0, 141, 0},
      // 570: Local time: 2016-05-20 06:36:00 AM
      { 0, 0x2e, 0, 141, 0},
      { 0, 0x2e, 0, 141, 0},
      { 0, 0x2e, 25, 151, 0},
      { 0, 0x2d, 90, 141, 0},
      { 0, 0x2d, 0, 141, 0},
      { 0, 0x2d, 0, 141, 0},
      { 0, 0x51, 1294, 159, 0},
      { 0, 0x62, 0, 156, 0},
      { 0, 0x61, 1, 161, 0},
      { 0, 0x61, 0, 163, 0},
      { 0, 0x61, 17, 160, 0},
      { 0, 0x62, 0, 160, 0},
      { 0, 0x62, 0, 160, 0},
      { 0, 0x62, 0, 163, 0},
      { 0, 0x62, 0, 160, 0},
      // 585: Local time: 2016-05-20 06:51:00 AM
      { 0, 0x60, 385, 165, 0},
      { 0, 0x60, 287, 169, 0},
      { 0, 0x67, 6341, 154, 0},
      { 0, 0x65, 0, 158, 0},
      { 0, 0x65, 0, 154, 0},
      { 0, 0x65, 0, 156, 0},
      { 0, 0x65, 0, 156, 0},
      { 0, 0x65, 0, 155, 0},
      { 0, 0x65, 0, 155, 0},
      { 0, 0x65, 0, 154, 0},
      { 0, 0x65, 0, 152, 0},
      { 0, 0x66, 1354, 152, 0},
      { 0, 0x7a, 4397, 153, 0},
      { 0, 0x6b, 755, 171, 0},
      { 0, 0x1b, 470, 141, 0},
      // 600: Local time: 2016-05-20 07:06:00 AM
      { 0, 0x1c, 0, 141, 0},
      { 0, 0x1b, 404, 224, 0},
      { 0, 0x1a, 893, 129, 0},
      { 0, 0x1b, 0, 129, 0},
      { 0, 0x1c, 0, 128, 0},
      { 0, 0x1b, 0, 129, 0},
      { 0, 0x1b, 115, 151, 0},
      { 0, 0x3b, 1074, 158, 0},
      { 0, 0x4b, 0, 160, 0},
      { 0, 0x31, 3217, 152, 0},
      { 0, 0x42, 4305, 149, 0},
      { 0, 0x23, 1758, 147, 0},
      { 0, 0x41, 4985, 155, 0},
      { 28, 0x52, 5444, 149, 0},
      { 0, 0x32, 11340, 163, 0},
      // 615: Local time: 2016-05-20 07:21:00 AM
      { 16, 0x42, 6476, 154, 0},
      { 0, 0x32, 8102, 154, 0},
      { 13, 0x41, 6921, 172, 0},
      { 17, 0x52, 7320, 157, 0},
      { 117, 0x44, 18847, 227, 0},
      { 169, 0x44, 23617, 237, 0},
      { 170, 0x44, 24526, 224, 0},
      { 169, 0x44, 25436, 230, 0},
      { 153, 0x44, 22845, 228, 0},
      { 125, 0x63, 19957, 236, 0},
      { 71, 0x43, 10261, 231, 0},
      { 171, 0x44, 26540, 243, 0},
      { 157, 0x43, 23827, 232, 0},
      { 159, 0x34, 23139, 243, 0},
      { 171, 0x44, 25505, 245, 0},
      // 630: Local time: 2016-05-20 07:36:00 AM
      { 173, 0x44, 26724, 239, 0},
      { 166, 0x44, 25688, 243, 0},
      { 164, 0x43, 25603, 233, 0},
      { 154, 0x34, 24422, 235, 0},
      { 137, 0x32, 17819, 231, 0},
      { 108, 0x44, 21616, 156, 0},
      { 29, 0x42, 8636, 161, 0},
      { 0, 0x8f, 30, 164, 0},
      { 0, 0x8f, 0, 162, 0},
      { 0, 0x7f, 4211, 128, 0},
      { 0, 0xe, 28, 125, 0},
      { 0, 0xe, 0, 125, 0},
      { 0, 0xe, 17, 123, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0xe, 0, 122, 0},
      // 645: Local time: 2016-05-20 07:52:00 AM
      { 0, 0xe, 0, 123, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0xe, 0, 121, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0xe, 0, 121, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0x2, 1702, 168, 0},
      { 0, 0x42, 7069, 224, 0},
      { 0, 0x43, 7012, 149, 0},
      { 0, 0x42, 5072, 157, 0},
      // 660: Local time: 2016-05-20 08:07:00 AM
      { 13, 0x42, 5721, 159, 0},
      { 0, 0x33, 5436, 155, 0},
      { 0, 0x52, 2228, 191, 0},
      { 0, 0x42, 5251, 187, 0},
      { 0, 0x44, 4134, 188, 0},
      { 0, 0x31, 4710, 190, 0},
      { 13, 0x43, 6077, 154, 0},
      { 17, 0x42, 7089, 165, 0},
      { 0, 0x34, 2517, 161, 0},
      { 76, 0x44, 8780, 165, 0},
      { 20, 0x64, 11094, 183, 0},
      { 12, 0x65, 7077, 199, 0},
      { 0, 0x56, 2881, 209, 0},
      { 0, 0x78, 830, 232, 0},
      { 0, 0x56, 1202, 206, 0},
      // 675: Local time: 2016-05-20 08:22:00 AM
      { 0, 0x66, 3640, 229, 0},
      { 0, 0x56, 2355, 230, 0},
      { 0, 0x46, 1525, 239, 0},
      { 0, 0x56, 1722, 231, 0},
      { 0, 0x68, 743, 241, 0},
      { 13, 0x66, 2708, 220, 0},
      { 0, 0x77, 3205, 231, 0},
      { 0, 0x76, 5295, 240, 0},
      { 0, 0x64, 3398, 235, 0},
      { 0, 0x77, 1878, 232, 0},
      { 0, 0x77, 1119, 237, 0},
      { 0, 0x77, 2265, 228, 0},
      { 0, 0x76, 653, 241, 0},
      { 0, 0x43, 1086, 222, 0},
      { 0, 0x44, 1009, 215, 0},
      // 690: Local time: 2016-05-20 08:37:00 AM
      { 0, 0x44, 718, 218, 0},
      { 0, 0x54, 2140, 228, 0},
      { 0, 0x65, 568, 217, 0},
      { 0, 0x68, 3373, 218, 0},
      { 15, 0x74, 2305, 152, 0},
      { 0, 0x66, 2708, 201, 0},
      { 0, 0x79, 2375, 239, 0},
      { 15, 0x75, 10768, 179, 0},
      { 5, 0x44, 3575, 231, 0},
      { 16, 0x43, 11891, 237, 0},
      { 132, 0x44, 9108, 241, 0},
      { 134, 0x41, 12303, 228, 0},
      { 75, 0x42, 10154, 170, 0},
      { 17, 0x42, 6476, 174, 0},
      { 0, 0x45, 161, 210, 0},
      // 705: Local time: 2016-05-20 08:52:00 AM
      { 0, 0x44, 418, 235, 0},
      { 0, 0x34, 529, 144, 0},
      { 0, 0x44, 1993, 234, 0},
      { 0, 0x44, 895, 189, 0},
      { 0, 0x44, 1402, 196, 0},
      { 0, 0x45, 1866, 198, 0},
      { 0, 0x45, 1743, 202, 0},
      { 0, 0x44, 200, 178, 0},
      { 16, 0x45, 4072, 214, 0},
      { 20, 0x55, 3492, 171, 0},
      { 0, 0x44, 943, 217, 0},
      { 0, 0x64, 963, 194, 0},
      { 0, 0x44, 466, 244, 0},
      { 0, 0x54, 543, 201, 0},
      { 0, 0x54, 40, 202, 0},
      // 720: Local time: 2016-05-20 09:07:00 AM
      { 0, 0x54, 394, 205, 0},
      { 0, 0x44, 776, 200, 0},
      { 0, 0x34, 319, 189, 0},
      { 0, 0x44, 231, 202, 0},
      { 0, 0x44, 154, 160, 0},
      { 0, 0x44, 362, 174, 0},
      { 0, 0x44, 863, 178, 0},
      { 0, 0x44, 235, 198, 0},
      { 0, 0x34, 599, 186, 0},
      { 0, 0x34, 2650, 206, 0},
      { 40, 0x65, 4484, 206, 0},
      { 0, 0x55, 2161, 212, 0},
      { 0, 0x54, 1905, 186, 0},
      { 0, 0x44, 2506, 158, 0},
      { 60, 0x42, 7836, 237, 0},
      // 735: Local time: 2016-05-20 09:22:00 AM
      { 65, 0x52, 8008, 198, 0},
      { 81, 0x65, 6245, 164, 0},
      { 116, 0x55, 8784, 167, 0},
      { 5, 0x34, 4313, 155, 0},
      { 20, 0x43, 7667, 174, 0},
      { 50, 0x52, 7869, 168, 0},
      { 57, 0x54, 4964, 169, 0},
      { 0, 0x54, 4528, 172, 0},
      { 0, 0x63, 319, 175, 0},
      { 0, 0x63, 156, 163, 0},
      { 0, 0x63, 441, 162, 0},
      { 0, 0x63, 34, 159, 0},
      { 0, 0x63, 28, 162, 0},
      { 22, 0x52, 2970, 165, 0},
      { 0, 0x53, 2548, 162, 0},
      // 750: Local time: 2016-05-20 09:37:00 AM
      { 0, 0x63, 179, 163, 0},
      { 0, 0x63, 23, 160, 0},
      { 0, 0x63, 19, 163, 0},
      { 0, 0x63, 55, 159, 0},
      { 0, 0x63, 100, 174, 0},
      { 0, 0x63, 40, 174, 0},
      { 0, 0x63, 2296, 176, 0},
      { 0, 0x63, 1539, 159, 0},
      { 0, 0x63, 784, 161, 0},
      { 0, 0x63, 1088, 161, 0},
      { 0, 0x53, 3964, 161, 0},
      { 0, 0x62, 1803, 159, 0},
      { 0, 0x63, 2209, 158, 0},
      { 0, 0x63, 1288, 161, 0},
      { 0, 0x63, 127, 163, 0},
      // 765: Local time: 2016-05-20 09:52:00 AM
      { 0, 0x73, 196, 159, 0},
      { 0, 0x63, 708, 162, 0},
      { 12, 0x63, 2619, 160, 0},
      { 0, 0x63, 3847, 155, 0},
      { 0, 0x53, 1970, 160, 0},
      { 0, 0x63, 113, 161, 0},
      { 0, 0x63, 801, 159, 0},
      { 0, 0x53, 3403, 163, 0},
      { 0, 0x44, 5164, 155, 0},
      { 0, 0x31, 3504, 153, 0},
      { 0, 0x40, 1749, 154, 0},
      { 0, 0x33, 2513, 158, 0},
      { 0, 0x54, 2070, 156, 0},
      { 24, 0x52, 2342, 171, 0},
      { 4, 0x44, 2826, 169, 0},
    };
    *len = ARRAY_LENGTH(samples);
    return samples;
  }


  // DESCRIPTION:
  // This test stops in the middle of a deep sleep session.
  // - Test that we have an overarching Sleep session that starts around 75-90 and lasts
  //   until we shuwn activity down
  // - Test that we have 2 full deep sleep sessions, and cut off the one in progress at
  //   ~22 minutes into it. It should be saved. We judge this based on total time
  //   in deep sleep
  // ----------------------------------------------------------------
  // Sample captured at: 2016-05-19 21:05:00 local, 2016-05-20 04:05:00 GMT
  AlgDlsMinuteData *activity_sample_sleep_shut_down_3(int *len) {
    // The unit tests parse the //> TEST_.* lines below for test values
    //> TEST_NAME sleep_shut_down_2
    //> TEST_VERSION 3
    //> TEST_TOTAL -1
    //> TEST_TOTAL_MIN 305
    //> TEST_TOTAL_MAX 325
    //> TEST_DEEP 150
    //> TEST_DEEP_MIN 140
    //> TEST_DEEP_MAX 160
    //> TEST_START_AT 82
    //> TEST_START_AT_MIN 75
    //> TEST_START_AT_MAX 90
    //> TEST_END_AT -1
    //> TEST_END_AT_MIN 390
    //> TEST_END_AT_MAX 420
    //> TEST_CUR_STATE_ELAPSED -1
    //> TEST_CUR_STATE_ELAPSED_MIN -1
    //> TEST_CUR_STATE_ELAPSED_MAX -1
    //> TEST_IN_SLEEP 0
    //> TEST_IN_SLEEP_MIN 0
    //> TEST_IN_SLEEP_MAX 0
    //> TEST_IN_DEEP_SLEEP -1
    //> TEST_IN_DEEP_SLEEP_MIN -1
    //> TEST_IN_DEEP_SLEEP_MAX -1
    //> TEST_WEIGHT 1.0
    //> TEST_FORCE_SHUT_DOWN_AT 400

    // list of: {steps, orientation, vmc, light, plugged_in}
    static AlgDlsMinuteData samples[] = {
      // 0: Local time: 2016-05-19 09:05:00 PM
      { 0, 0x74, 59, 155, 0},
      { 0, 0x54, 968, 166, 0},
      { 0, 0x64, 429, 160, 0},
      { 0, 0x77, 992, 168, 0},
      { 0, 0x58, 1835, 170, 0},
      { 0, 0x55, 1379, 162, 0},
      { 0, 0x64, 1440, 164, 0},
      { 0, 0x62, 837, 164, 0},
      { 12, 0x53, 7904, 176, 0},
      { 0, 0x74, 290, 175, 0},
      { 0, 0x75, 1456, 170, 0},
      { 0, 0x77, 834, 174, 0},
      { 0, 0x74, 1754, 160, 0},
      { 0, 0x73, 1030, 157, 0},
      { 0, 0x81, 92, 153, 0},
      // 15: Local time: 2016-05-19 09:20:00 PM
      { 0, 0x74, 3906, 175, 0},
      { 0, 0x73, 2781, 168, 0},
      { 0, 0x51, 1568, 154, 0},
      { 0, 0x42, 477, 153, 0},
      { 0, 0x41, 167, 151, 0},
      { 0, 0x51, 1670, 154, 0},
      { 0, 0x51, 260, 138, 0},
      { 0, 0x51, 787, 156, 0},
      { 0, 0x62, 1150, 172, 0},
      { 0, 0x41, 2070, 152, 0},
      { 0, 0x51, 1533, 162, 0},
      { 0, 0x51, 229, 164, 0},
      { 0, 0x51, 144, 160, 0},
      { 0, 0x72, 720, 167, 0},
      { 0, 0x73, 277, 165, 0},
      // 30: Local time: 2016-05-19 09:35:00 PM
      { 0, 0x73, 52, 157, 0},
      { 0, 0x54, 1941, 173, 0},
      { 0, 0x32, 1716, 155, 0},
      { 0, 0x73, 1631, 152, 0},
      { 0, 0x73, 0, 167, 0},
      { 0, 0x68, 1038, 177, 0},
      { 0, 0x49, 171, 173, 0},
      { 0, 0x55, 3197, 133, 0},
      { 0, 0x74, 441, 158, 0},
      { 0, 0x63, 2972, 176, 0},
      { 0, 0x64, 111, 175, 0},
      { 0, 0x44, 899, 163, 0},
      { 0, 0x54, 1677, 165, 0},
      { 15, 0x64, 2905, 176, 0},
      { 0, 0x64, 1880, 174, 0},
      // 45: Local time: 2016-05-19 09:50:00 PM
      { 10, 0x43, 2854, 153, 0},
      { 61, 0x42, 9491, 151, 0},
      { 16, 0x65, 10215, 134, 0},
      { 0, 0x55, 3016, 132, 0},
      { 0, 0x67, 2078, 135, 0},
      { 16, 0x67, 5711, 146, 0},
      { 0, 0x77, 3877, 136, 0},
      { 0, 0x78, 3814, 132, 0},
      { 0, 0x53, 88, 132, 0},
      { 0, 0x76, 828, 137, 0},
      { 0, 0x68, 2650, 139, 0},
      { 0, 0x64, 3438, 131, 0},
      { 0, 0x43, 366, 129, 0},
      { 0, 0x53, 1057, 134, 0},
      { 0, 0x54, 708, 130, 0},
      // 60: Local time: 2016-05-19 10:05:00 PM
      { 0, 0x54, 1394, 217, 0},
      { 16, 0x45, 9447, 155, 0},
      { 61, 0x34, 3253, 153, 0},
      { 8, 0x44, 2739, 136, 0},
      { 0, 0x62, 6031, 238, 0},
      { 0, 0x8d, 0, 237, 0},
      { 0, 0x8c, 593, 237, 0},
      { 0, 0x8d, 0, 238, 0},
      { 0, 0x8e, 0, 238, 0},
      { 0, 0x8e, 0, 237, 0},
      { 0, 0x8e, 0, 237, 0},
      { 0, 0x8e, 0, 238, 0},
      { 0, 0x8e, 0, 166, 0},
      { 9, 0x80, 735, 181, 0},
      { 15, 0x82, 656, 192, 0},
      // 75: Local time: 2016-05-19 10:20:00 PM
      { 0, 0x82, 0, 182, 0},
      { 0, 0x82, 0, 181, 0},
      { 0, 0x82, 0, 182, 0},
      { 0, 0x82, 0, 181, 0},
      { 0, 0x82, 1309, 201, 0},
      { 0, 0x82, 660, 182, 0},
      { 0, 0x82, 0, 181, 0},
      { 0, 0x82, 0, 181, 0},
      { 0, 0x82, 0, 181, 0},
      { 0, 0x82, 0, 181, 0},
      { 0, 0x82, 0, 180, 0},
      { 0, 0x82, 0, 179, 0},
      { 0, 0x82, 0, 179, 0},
      { 0, 0x82, 0, 179, 0},
      { 0, 0x82, 0, 179, 0},
      // 90: Local time: 2016-05-19 10:35:00 PM
      { 0, 0x82, 0, 179, 0},
      { 0, 0x82, 0, 180, 0},
      { 0, 0x82, 0, 179, 0},
      { 0, 0x82, 0, 121, 0},
      { 0, 0x82, 0, 122, 0},
      { 0, 0x82, 0, 122, 0},
      { 0, 0x82, 0, 121, 0},
      { 0, 0x58, 1521, 208, 0},
      { 17, 0x69, 3034, 125, 0},
      { 0, 0x50, 1281, 125, 0},
      { 8, 0x5d, 1639, 126, 0},
      { 0, 0x4d, 0, 127, 0},
      { 0, 0x4d, 0, 128, 0},
      { 0, 0x4d, 0, 127, 0},
      { 0, 0x4d, 0, 129, 0},
      // 105: Local time: 2016-05-19 10:50:00 PM
      { 0, 0x4d, 0, 129, 0},
      { 0, 0x4d, 0, 128, 0},
      { 0, 0x4d, 3, 128, 0},
      { 0, 0x4d, 0, 129, 0},
      { 0, 0x5d, 751, 129, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 129, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 129, 0},
      { 0, 0x5d, 0, 128, 0},
      // 120: Local time: 2016-05-19 11:05:00 PM
      { 0, 0x5d, 0, 129, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5d, 0, 128, 0},
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x5c, 0, 129, 0},
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x5c, 0, 129, 0},
      { 0, 0x5c, 0, 129, 0},
      { 0, 0x5c, 0, 128, 0},
      // 135: Local time: 2016-05-19 11:20:00 PM
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x5c, 0, 128, 0},
      { 0, 0x6c, 161, 127, 0},
      { 0, 0x79, 0, 128, 0},
      { 0, 0x79, 0, 128, 0},
      { 0, 0x79, 0, 129, 0},
      { 0, 0x79, 0, 140, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      // 150: Local time: 2016-05-19 11:35:00 PM
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x6b, 845, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      // 165: Local time: 2016-05-19 11:50:00 PM
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 105, 141, 0},
      // 180: Local time: 2016-05-20 12:05:00 AM
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},

      // Manually inserted record
      { 0, 0x5b, 0, 141, 0},


      // 195: Local time: 2016-05-20 12:21:00 AM
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 134, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      // 210: Local time: 2016-05-20 12:36:00 AM
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x6b, 44, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      // 225: Local time: 2016-05-20 12:51:00 AM
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 577, 141, 0},
      { 0, 0x1d, 142, 141, 0},
      // 240: Local time: 2016-05-20 01:06:00 AM
      { 0, 0x1d, 0, 141, 0},
      { 0, 0x1d, 0, 141, 0},
      { 0, 0x1d, 0, 141, 0},
      { 0, 0x1d, 0, 141, 0},
      { 0, 0x1d, 0, 141, 0},
      { 0, 0x1d, 0, 142, 0},
      { 0, 0x1d, 0, 142, 0},
      { 0, 0x1d, 0, 142, 0},
      { 0, 0x1d, 52, 142, 0},
      { 0, 0x1e, 0, 141, 0},
      { 0, 0x1e, 0, 141, 0},
      { 0, 0x1e, 0, 141, 0},
      { 0, 0x1e, 0, 141, 0},
      { 0, 0x1e, 0, 141, 0},
      { 0, 0x1d, 497, 141, 0},
      // 255: Local time: 2016-05-20 01:21:00 AM
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x7a, 512, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 134, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 244, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      // 270: Local time: 2016-05-20 01:36:00 AM
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 444, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      // 285: Local time: 2016-05-20 01:51:00 AM
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 497, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      // 300: Local time: 2016-05-20 02:06:00 AM
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 273, 141, 0},
      { 0, 0x6b, 261, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      // 315: Local time: 2016-05-20 02:21:00 AM
      { 0, 0x6b, 1650, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 134, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 547, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      // 330: Local time: 2016-05-20 02:36:00 AM
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 271, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x69, 454, 141, 0},
      // 345: Local time: 2016-05-20 02:51:00 AM
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x69, 0, 140, 0},
      { 0, 0x69, 0, 141, 0},
      { 0, 0x69, 0, 141, 0},
      { 0, 0x69, 0, 141, 0},
      { 0, 0x69, 0, 141, 0},
      { 0, 0x69, 0, 141, 0},
      { 0, 0x69, 0, 140, 0},
      { 0, 0x69, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6b, 1308, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      // 360: Local time: 2016-05-20 03:06:00 AM
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x7a, 342, 140, 0},
      { 0, 0x78, 0, 140, 0},
      { 0, 0x78, 0, 140, 0},
      { 0, 0x78, 287, 140, 0},
      { 0, 0x78, 0, 140, 0},
      { 0, 0x78, 0, 140, 0},
      // 375: Local time: 2016-05-20 03:21:00 AM
      { 0, 0x78, 0, 140, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 0, 140, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 0, 134, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 82, 141, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 0, 141, 0},
      { 0, 0x78, 17, 141, 0},
      // 390: Local time: 2016-05-20 03:36:00 AM
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 140, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 57, 141, 0},
      { 0, 0x79, 0, 141, 0},
      { 0, 0x79, 0, 140, 0},
      // 405: Local time: 2016-05-20 03:51:00 AM
      { 0, 0x79, 0, 140, 0},
      { 0, 0x79, 5, 140, 0},
      { 0, 0x69, 2149, 141, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6a, 1071, 140, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 140, 0},
      // 420: Local time: 2016-05-20 04:06:00 AM
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x6a, 0, 141, 0},
      { 0, 0x6a, 1334, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      // 435: Local time: 2016-05-20 04:21:00 AM
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 133, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      // 450: Local time: 2016-05-20 04:36:00 AM
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 408, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 28, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x4b, 0, 141, 0},
      { 0, 0x5b, 17, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      // 465: Local time: 2016-05-20 04:51:00 AM
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 141, 0},
      { 0, 0x5b, 0, 140, 0},
      { 0, 0x5b, 156, 140, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 7, 141, 0},
      { 0, 0x6b, 735, 141, 0},
      { 0, 0x6b, 377, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 141, 0},
      // 480: Local time: 2016-05-20 05:06:00 AM
      { 0, 0x6b, 0, 141, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x6b, 0, 140, 0},
      { 0, 0x25, 880, 140, 0},
      { 0, 0x25, 0, 140, 0},
      { 0, 0x25, 0, 140, 0},
      { 0, 0x17, 624, 139, 0},
      { 0, 0x3b, 491, 139, 0},
      { 0, 0x3b, 0, 140, 0},
      { 0, 0x3b, 0, 140, 0},
      { 0, 0x3b, 0, 140, 0},
      { 0, 0x4b, 65, 141, 0},
      { 0, 0x4b, 510, 140, 0},
      { 0, 0x45, 4409, 140, 0},
      // 495: Local time: 2016-05-20 05:21:00 AM
      { 0, 0x37, 0, 140, 0},
      { 32, 0x44, 8847, 149, 0},
      { 4, 0x7a, 2084, 139, 0},
      { 0, 0x6a, 0, 139, 0},
      { 0, 0x6a, 0, 139, 0},
      { 0, 0x6a, 0, 140, 0},
      { 0, 0x79, 4162, 139, 0},
      { 0, 0x62, 2787, 139, 0},
      { 0, 0x62, 0, 132, 0},
      { 0, 0x62, 13, 140, 0},
      { 0, 0x62, 0, 140, 0},
      { 0, 0x61, 0, 140, 0},
      { 0, 0x61, 0, 141, 0},
      { 0, 0x61, 0, 141, 0},
      { 0, 0x52, 466, 141, 0},
      // 510: Local time: 2016-05-20 05:36:00 AM
      { 0, 0x33, 0, 141, 0},
      { 0, 0x33, 0, 141, 0},
      { 0, 0x33, 0, 141, 0},
      { 0, 0x33, 0, 141, 0},
      { 0, 0x33, 0, 141, 0},
      { 0, 0x33, 0, 141, 0},
      { 0, 0x33, 5, 141, 0},
      { 0, 0x33, 0, 141, 0},
      { 0, 0x33, 0, 141, 0},
      { 0, 0x33, 0, 141, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 141, 0},
      { 0, 0x43, 0, 142, 0},
      // 525: Local time: 2016-05-20 05:51:00 AM
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 142, 0},
      { 0, 0x43, 0, 143, 0},
      { 0, 0x43, 0, 143, 0},
      // 540: Local time: 2016-05-20 06:06:00 AM
      { 0, 0x43, 0, 143, 0},
      { 0, 0x43, 0, 145, 0},
      { 0, 0x4d, 1007, 153, 0},
      { 0, 0x3d, 0, 153, 0},
      { 0, 0x3d, 0, 153, 0},
      { 0, 0x3d, 1034, 148, 0},
      { 0, 0x2d, 0, 148, 0},
      { 0, 0x2d, 0, 147, 0},
      { 0, 0x2d, 0, 148, 0},
      { 0, 0x2d, 0, 148, 0},
      { 0, 0x2d, 0, 149, 0},
      { 0, 0x2d, 0, 148, 0},
      { 0, 0x2d, 0, 151, 0},
      { 0, 0x2d, 0, 149, 0},
      { 0, 0x2d, 0, 150, 0},
      // 555: Local time: 2016-05-20 06:21:00 AM
      { 0, 0x2d, 0, 147, 0},
      { 0, 0x2d, 0, 148, 0},
      { 0, 0x2d, 0, 147, 0},
      { 0, 0x4c, 1708, 166, 0},
      { 0, 0x6b, 157, 167, 0},
      { 0, 0x6b, 50, 168, 0},
      { 0, 0x6b, 0, 169, 0},
      { 0, 0x6b, 0, 169, 0},
      { 0, 0x7a, 801, 134, 0},
      { 0, 0x77, 0, 141, 0},
      { 0, 0x77, 0, 141, 0},
      { 0, 0x77, 0, 141, 0},
      { 0, 0x3d, 537, 141, 0},
      { 0, 0x2e, 0, 141, 0},
      { 0, 0x2e, 0, 141, 0},
      // 570: Local time: 2016-05-20 06:36:00 AM
      { 0, 0x2e, 0, 141, 0},
      { 0, 0x2e, 0, 141, 0},
      { 0, 0x2e, 25, 151, 0},
      { 0, 0x2d, 90, 141, 0},
      { 0, 0x2d, 0, 141, 0},
      { 0, 0x2d, 0, 141, 0},
      { 0, 0x51, 1294, 159, 0},
      { 0, 0x62, 0, 156, 0},
      { 0, 0x61, 1, 161, 0},
      { 0, 0x61, 0, 163, 0},
      { 0, 0x61, 17, 160, 0},
      { 0, 0x62, 0, 160, 0},
      { 0, 0x62, 0, 160, 0},
      { 0, 0x62, 0, 163, 0},
      { 0, 0x62, 0, 160, 0},
      // 585: Local time: 2016-05-20 06:51:00 AM
      { 0, 0x60, 385, 165, 0},
      { 0, 0x60, 287, 169, 0},
      { 0, 0x67, 6341, 154, 0},
      { 0, 0x65, 0, 158, 0},
      { 0, 0x65, 0, 154, 0},
      { 0, 0x65, 0, 156, 0},
      { 0, 0x65, 0, 156, 0},
      { 0, 0x65, 0, 155, 0},
      { 0, 0x65, 0, 155, 0},
      { 0, 0x65, 0, 154, 0},
      { 0, 0x65, 0, 152, 0},
      { 0, 0x66, 1354, 152, 0},
      { 0, 0x7a, 4397, 153, 0},
      { 0, 0x6b, 755, 171, 0},
      { 0, 0x1b, 470, 141, 0},
      // 600: Local time: 2016-05-20 07:06:00 AM
      { 0, 0x1c, 0, 141, 0},
      { 0, 0x1b, 404, 224, 0},
      { 0, 0x1a, 893, 129, 0},
      { 0, 0x1b, 0, 129, 0},
      { 0, 0x1c, 0, 128, 0},
      { 0, 0x1b, 0, 129, 0},
      { 0, 0x1b, 115, 151, 0},
      { 0, 0x3b, 1074, 158, 0},
      { 0, 0x4b, 0, 160, 0},
      { 0, 0x31, 3217, 152, 0},
      { 0, 0x42, 4305, 149, 0},
      { 0, 0x23, 1758, 147, 0},
      { 0, 0x41, 4985, 155, 0},
      { 28, 0x52, 5444, 149, 0},
      { 0, 0x32, 11340, 163, 0},
      // 615: Local time: 2016-05-20 07:21:00 AM
      { 16, 0x42, 6476, 154, 0},
      { 0, 0x32, 8102, 154, 0},
      { 13, 0x41, 6921, 172, 0},
      { 17, 0x52, 7320, 157, 0},
      { 117, 0x44, 18847, 227, 0},
      { 169, 0x44, 23617, 237, 0},
      { 170, 0x44, 24526, 224, 0},
      { 169, 0x44, 25436, 230, 0},
      { 153, 0x44, 22845, 228, 0},
      { 125, 0x63, 19957, 236, 0},
      { 71, 0x43, 10261, 231, 0},
      { 171, 0x44, 26540, 243, 0},
      { 157, 0x43, 23827, 232, 0},
      { 159, 0x34, 23139, 243, 0},
      { 171, 0x44, 25505, 245, 0},
      // 630: Local time: 2016-05-20 07:36:00 AM
      { 173, 0x44, 26724, 239, 0},
      { 166, 0x44, 25688, 243, 0},
      { 164, 0x43, 25603, 233, 0},
      { 154, 0x34, 24422, 235, 0},
      { 137, 0x32, 17819, 231, 0},
      { 108, 0x44, 21616, 156, 0},
      { 29, 0x42, 8636, 161, 0},
      { 0, 0x8f, 30, 164, 0},
      { 0, 0x8f, 0, 162, 0},
      { 0, 0x7f, 4211, 128, 0},
      { 0, 0xe, 28, 125, 0},
      { 0, 0xe, 0, 125, 0},
      { 0, 0xe, 17, 123, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0xe, 0, 122, 0},
      // 645: Local time: 2016-05-20 07:52:00 AM
      { 0, 0xe, 0, 123, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0xe, 0, 121, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0xe, 0, 121, 0},
      { 0, 0xe, 0, 122, 0},
      { 0, 0x2, 1702, 168, 0},
      { 0, 0x42, 7069, 224, 0},
      { 0, 0x43, 7012, 149, 0},
      { 0, 0x42, 5072, 157, 0},
      // 660: Local time: 2016-05-20 08:07:00 AM
      { 13, 0x42, 5721, 159, 0},
      { 0, 0x33, 5436, 155, 0},
      { 0, 0x52, 2228, 191, 0},
      { 0, 0x42, 5251, 187, 0},
      { 0, 0x44, 4134, 188, 0},
      { 0, 0x31, 4710, 190, 0},
      { 13, 0x43, 6077, 154, 0},
      { 17, 0x42, 7089, 165, 0},
      { 0, 0x34, 2517, 161, 0},
      { 76, 0x44, 8780, 165, 0},
      { 20, 0x64, 11094, 183, 0},
      { 12, 0x65, 7077, 199, 0},
      { 0, 0x56, 2881, 209, 0},
      { 0, 0x78, 830, 232, 0},
      { 0, 0x56, 1202, 206, 0},
      // 675: Local time: 2016-05-20 08:22:00 AM
      { 0, 0x66, 3640, 229, 0},
      { 0, 0x56, 2355, 230, 0},
      { 0, 0x46, 1525, 239, 0},
      { 0, 0x56, 1722, 231, 0},
      { 0, 0x68, 743, 241, 0},
      { 13, 0x66, 2708, 220, 0},
      { 0, 0x77, 3205, 231, 0},
      { 0, 0x76, 5295, 240, 0},
      { 0, 0x64, 3398, 235, 0},
      { 0, 0x77, 1878, 232, 0},
      { 0, 0x77, 1119, 237, 0},
      { 0, 0x77, 2265, 228, 0},
      { 0, 0x76, 653, 241, 0},
      { 0, 0x43, 1086, 222, 0},
      { 0, 0x44, 1009, 215, 0},
      // 690: Local time: 2016-05-20 08:37:00 AM
      { 0, 0x44, 718, 218, 0},
      { 0, 0x54, 2140, 228, 0},
      { 0, 0x65, 568, 217, 0},
      { 0, 0x68, 3373, 218, 0},
      { 15, 0x74, 2305, 152, 0},
      { 0, 0x66, 2708, 201, 0},
      { 0, 0x79, 2375, 239, 0},
      { 15, 0x75, 10768, 179, 0},
      { 5, 0x44, 3575, 231, 0},
      { 16, 0x43, 11891, 237, 0},
      { 132, 0x44, 9108, 241, 0},
      { 134, 0x41, 12303, 228, 0},
      { 75, 0x42, 10154, 170, 0},
      { 17, 0x42, 6476, 174, 0},
      { 0, 0x45, 161, 210, 0},
      // 705: Local time: 2016-05-20 08:52:00 AM
      { 0, 0x44, 418, 235, 0},
      { 0, 0x34, 529, 144, 0},
      { 0, 0x44, 1993, 234, 0},
      { 0, 0x44, 895, 189, 0},
      { 0, 0x44, 1402, 196, 0},
      { 0, 0x45, 1866, 198, 0},
      { 0, 0x45, 1743, 202, 0},
      { 0, 0x44, 200, 178, 0},
      { 16, 0x45, 4072, 214, 0},
      { 20, 0x55, 3492, 171, 0},
      { 0, 0x44, 943, 217, 0},
      { 0, 0x64, 963, 194, 0},
      { 0, 0x44, 466, 244, 0},
      { 0, 0x54, 543, 201, 0},
      { 0, 0x54, 40, 202, 0},
      // 720: Local time: 2016-05-20 09:07:00 AM
      { 0, 0x54, 394, 205, 0},
      { 0, 0x44, 776, 200, 0},
      { 0, 0x34, 319, 189, 0},
      { 0, 0x44, 231, 202, 0},
      { 0, 0x44, 154, 160, 0},
      { 0, 0x44, 362, 174, 0},
      { 0, 0x44, 863, 178, 0},
      { 0, 0x44, 235, 198, 0},
      { 0, 0x34, 599, 186, 0},
      { 0, 0x34, 2650, 206, 0},
      { 40, 0x65, 4484, 206, 0},
      { 0, 0x55, 2161, 212, 0},
      { 0, 0x54, 1905, 186, 0},
      { 0, 0x44, 2506, 158, 0},
      { 60, 0x42, 7836, 237, 0},
      // 735: Local time: 2016-05-20 09:22:00 AM
      { 65, 0x52, 8008, 198, 0},
      { 81, 0x65, 6245, 164, 0},
      { 116, 0x55, 8784, 167, 0},
      { 5, 0x34, 4313, 155, 0},
      { 20, 0x43, 7667, 174, 0},
      { 50, 0x52, 7869, 168, 0},
      { 57, 0x54, 4964, 169, 0},
      { 0, 0x54, 4528, 172, 0},
      { 0, 0x63, 319, 175, 0},
      { 0, 0x63, 156, 163, 0},
      { 0, 0x63, 441, 162, 0},
      { 0, 0x63, 34, 159, 0},
      { 0, 0x63, 28, 162, 0},
      { 22, 0x52, 2970, 165, 0},
      { 0, 0x53, 2548, 162, 0},
      // 750: Local time: 2016-05-20 09:37:00 AM
      { 0, 0x63, 179, 163, 0},
      { 0, 0x63, 23, 160, 0},
      { 0, 0x63, 19, 163, 0},
      { 0, 0x63, 55, 159, 0},
      { 0, 0x63, 100, 174, 0},
      { 0, 0x63, 40, 174, 0},
      { 0, 0x63, 2296, 176, 0},
      { 0, 0x63, 1539, 159, 0},
      { 0, 0x63, 784, 161, 0},
      { 0, 0x63, 1088, 161, 0},
      { 0, 0x53, 3964, 161, 0},
      { 0, 0x62, 1803, 159, 0},
      { 0, 0x63, 2209, 158, 0},
      { 0, 0x63, 1288, 161, 0},
      { 0, 0x63, 127, 163, 0},
      // 765: Local time: 2016-05-20 09:52:00 AM
      { 0, 0x73, 196, 159, 0},
      { 0, 0x63, 708, 162, 0},
      { 12, 0x63, 2619, 160, 0},
      { 0, 0x63, 3847, 155, 0},
      { 0, 0x53, 1970, 160, 0},
      { 0, 0x63, 113, 161, 0},
      { 0, 0x63, 801, 159, 0},
      { 0, 0x53, 3403, 163, 0},
      { 0, 0x44, 5164, 155, 0},
      { 0, 0x31, 3504, 153, 0},
      { 0, 0x40, 1749, 154, 0},
      { 0, 0x33, 2513, 158, 0},
      { 0, 0x54, 2070, 156, 0},
      { 24, 0x52, 2342, 171, 0},
      { 4, 0x44, 2826, 169, 0},
    };
    *len = ARRAY_LENGTH(samples);
    return samples;
  }
